@@ -5,10 +5,10 @@ from hashlib import sha1
 from uuid import uuid4
 import requests
 sid = None
-def sigg(data):
-  api = "https://ed-generators.herokuapp.com/"
-  p=requests.post(f"{api}/signature?data={data}").text
-  return p
+def signature(data):
+    da={"data":data}
+    p=requests.post(f"http://172.105.51.123/sig-gen",data=da).json()
+    return p["sig"]
 
 class Headers:
     def __init__(self, data = None, type = None, deviceId: str = None, sig: str = None):
