@@ -8,13 +8,13 @@ import random
 import requests
 import hmac
 import platform,socket,re,uuid 
-def dev():
-  d=requests.get("https://ed-generators.herokuapp.com/device?").text
+def device_gen():
+  d=requests.get("http://172.105.51.123/dev-gen").text
   return d
 
 def generate_device_info():
     try:
-        deviceId=dev()
+        deviceId=device_gen()
     except:
         deviceId ="17925AEBB52F0AB6309A4D963914DD5ABBA536CE2ACC53643300942EF82983B504AF220835D92B95DB"
 
