@@ -35,9 +35,9 @@ class SocketHandler:
         threading.Thread(target=self.reconnect_handler).start()
         websocket.enableTrace(self.socket_trace)
     def signature(self,data):
-        api = "https://ed-generators.herokuapp.com/"
-        p=requests.post(f"{api}/signature?data={data}").text
-        return p
+        da={"data":data}
+        p=requests.post(f"http://192.46.224.23/sig-gen",data=da).json()
+        return p["sig"]
 
     def reconnect_handler(self):
         # Made by enchart#3410 thx
